@@ -1,5 +1,5 @@
 /*!
-# 🔥 afire <a href="https://github.com/Basicprogrammer10/afire/actions"><img src="https://img.shields.io/github/workflow/status/Basicprogrammer10/afire/CI?label=Tests"></a> <a href="#"><img src="https://img.shields.io/tokei/lines/github/Basicprogrammer10/afire?label=Total%20Lines"></a> <a href="https://crates.io/crates/afire"><img src="https://img.shields.io/crates/d/afire?label=Downloads"></a>
+# 🔥 afire <a href="https://github.com/Basicprogrammer10/afire/actions"><img src="https://img.shields.io/github/workflow/status/Basicprogrammer10/afire/CI?label=Tests"></a> <a href="#"><img src="https://img.shields.io/tokei/lines/github/Basicprogrammer10/afire?label=Total%20Lines"></a> <a href="https://crates.io/crates/afire"><img alt="Crates.io" src="https://img.shields.io/crates/v/afire"> <img src="https://img.shields.io/crates/d/afire?label=Downloads"></a>
 
 A blazing fast dependency free web framework for Rust
 
@@ -9,7 +9,7 @@ Just add the following to your `Cargo.toml`:
 
 ```toml
 [dependencies]
-afire = "1.0.0"
+afire = "1.1.0"
 ```
 
 ## 📄 Info
@@ -59,7 +59,7 @@ For these you will need to enable the features.
 To use these extra features enable them like this:
 
 ```toml
-afire = { version = "1.0.0", features = ["rate_limit", "logging", "serve_static"] }
+afire = { version = "1.1.0", features = ["rate_limit", "logging", "serve_static"] }
 ```
 
 - Content Types
@@ -92,7 +92,7 @@ server.start().unwrap();
 #![warn(missing_docs)]
 
 #[doc(hidden)]
-pub const VERSION: &str = "1.0.0";
+pub const VERSION: &str = "1.1.0";
 
 // Export Internal Functions
 #[macro_use]
